defmodule DecentralisedBookIndexWeb.AuthorLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  alias DecentralisedBookIndex.Accounts.Role

  @impl true
  def render(assigns) do
    ~H"""
    <.header class="flex-col lg:flex-row">
      {@author.name}

      <:actions>
        <%= if @current_user != nil and Role.can_moderate?(@current_user.role) do %>
          <div class="flex flex-row gap-2">
            <.add_button_link patch={~p"/authors/#{@author}/new"}>
              Alias
            </.add_button_link>
            <%= if is_nil(@author.dbi_server) do %>
              <.link patch={~p"/authors/#{@author}/edit"}>
                <.edit_button>
                  Edit
                </.edit_button>
              </.link>
            <% end %>
          </div>
        <% end %>
      </:actions>
    </.header>

    <div class="flex flex-col items-start gap-6 max-w-6xl mx-auto p-4 bg-gray-900 rounded-lg transition-all duration-300 md:prose md:block">
      <%= if @author.avatar_url != nil do %>
        <img
          class="w-36 h-36 mb-3 rounded-full shadow-lg mx-auto md:float-left md:mr-4"
          src={@author.avatar_url}
          alt={"#{@author.name} image"}
        />
      <% else %>
        <div class="relative w-36 h-36 overflow-hidden bg-gray-100 rounded-full dark:bg-gray-600 mx-auto md:float-left md:mr-4">
          <svg
            class="absolute w-36 h-36 text-gray-400"
            fill="currentColor"
            viewBox="0 0 20 20"
            xmlns="http://www.w3.org/2000/svg"
          >
            <path
              fill-rule="evenodd"
              d="M10 9a3 3 0 100-6 3 3 0 000 6zm-7 9a7 7 0 1114 0H3z"
              clip-rule="evenodd"
            >
            </path>
          </svg>
        </div>
      <% end %>

      <div class="flex-1 pt-2 lg:pt-0 min-h-36">
        <h2 class="mb-2 font-semibold leading-none text-gray-900 dark:text-white">Description</h2>
        <p class="text-gray-300 leading-relaxed">
          {@author.description}
        </p>

        <%= if not is_nil(@author.dbi_server) do %>
          <dl>
            <dt class="mt-4 mb-2 font-semibold leading-none text-gray-900 dark:text-white">
              From Server
            </dt>
            <dd class="mb-4 font-light text-gray-500 sm:mb-5 dark:text-gray-400">
              <%= if @current_user != nil and Role.can_moderate?(@current_user.role) do %>
                <.link navigate={~p"/servers/#{@author.dbi_server.id}/"} class="hover:underline">
                  {@author.dbi_server.name}
                </.link>
              <% else %>
                <.link navigate={@author.dbi_server.url} class="hover:underline">
                  {@author.dbi_server.name}
                </.link>
              <% end %>
            </dd>
          </dl>
        <% end %>
      </div>
    </div>

    <%= if @alternative_names != [] do %>
      <h2 class="mb-2 text-lg font-semibold text-gray-900 dark:text-white mt-10">
        Alternatives names
      </h2>
      <ul class="max-w-md space-y-1 text-gray-700 list-disc list-inside dark:text-white">
        <%= for alias_author <- @alternative_names do %>
          <.link navigate={~p"/authors/#{alias_author.id}"}>
            <li>
              <span class="no-underline hover:underline">
                {alias_author.name}
              </span>
            </li>
          </.link>
        <% end %>
      </ul>
    <% end %>

    <.back navigate={~p"/authors"}>Back to authors</.back>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    author =
      Ash.get!(DecentralisedBookIndex.Metadata.Author, id, load: [:dbi_server], actor: socket.assigns.current_user)

    alternative_names = DecentralisedBookIndex.Metadata.get_author_alternative_names!(author)

    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(:author, author)
     |> assign(:alternative_names, alternative_names)}
  end

  defp page_title(:show), do: "Show Author"
  defp page_title(:edit), do: "Edit Author"
end
