defmodule DecentralisedBookIndexWeb.PublisherLive.Show do
  use DecentralisedBookIndexWeb, :live_view

  alias DecentralisedBookIndex.Accounts.Role

  @impl true
  def render(assigns) do
    ~H"""
    <.header class="flex-col lg:flex-row">
      {@publisher.name}

      <:actions>
        <%= if is_nil(@publisher.dbi_server) do %>
          <.link patch={~p"/publishers/#{@publisher}/edit"} phx-click={JS.push_focus()}>
            <.edit_button>
              Edit
            </.edit_button>
          </.link>
        <% end %>
      </:actions>
    </.header>

    <%= if not is_nil(@publisher.dbi_server) do %>
      <div>
        <dl>
          <dt class="mt-4 mb-2 font-semibold leading-none text-gray-900 dark:text-white">
            From Server
          </dt>
          <dd class="mb-4 font-light text-gray-500 sm:mb-5 dark:text-gray-400">
            <%= if @current_user != nil and Role.can_moderate?(@current_user.role) do %>
              <.link navigate={~p"/servers/#{@publisher.dbi_server.id}/"} class="hover:underline">
                {@publisher.dbi_server.name}
              </.link>
            <% else %>
              <.link navigate={@publisher.dbi_server.url} class="hover:underline">
                {@publisher.dbi_server.name}
              </.link>
            <% end %>
          </dd>
        </dl>
      </div>
    <% end %>

    <.back navigate={~p"/publishers"}>Back to publishers</.back>
    """
  end

  @impl true
  def mount(_params, _session, socket) do
    {:ok, socket}
  end

  @impl true
  def handle_params(%{"id" => id}, _, socket) do
    {:noreply,
     socket
     |> assign(:page_title, page_title(socket.assigns.live_action))
     |> assign(
       :publisher,
       Ash.get!(DecentralisedBookIndex.Metadata.Publisher, id, load: [:dbi_server], actor: socket.assigns.current_user)
     )}
  end

  defp page_title(:show), do: "Show Publisher"
  defp page_title(:edit), do: "Edit Publisher"
end
