defmodule DecentralisedBookIndex.Sync.DataTransformers.DBIServerTransformerTest do
  use ExUnit.Case, async: true

  alias DecentralisedBookIndex.Sync.DataTransformers.DBIServerTransformer

  describe "correct transformations" do
    test "a json contains correct author information" do
      json_body = %{
        "data" => %{
          "attributes" => %{
            "dbi_server_id" => "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
            "inserted_at" => "2025-03-22T20:07:30.766249Z",
            "name" => "Test",
            "updated_at" => "2025-05-04T18:48:44.213309Z",
            "url" => "http://localhost:4001"
          },
          "id" => "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
          "links" => %{},
          "meta" => %{},
          "relationships" => %{"dbi_server" => %{"links" => %{}, "meta" => %{}}},
          "type" => "dbi_server"
        },
        "jsonapi" => %{"version" => "1.0"},
        "links" => %{
          "self" =>
            "http://localhost:4000/api/v1/json/servers/0c0647ec-07ef-4caa-b683-5847dbfbe5cc"
        },
        "meta" => %{}
      }

      assert {:ok, server} = DBIServerTransformer.from_json(json_body)

      assert %{
               id: "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
               name: "Test",
               url: "http://localhost:4001",
               inserted_at: "2025-03-22T20:07:30.766249Z",
               updated_at: "2025-05-04T18:48:44.213309Z",
               dbi_server_id: "0c0647ec-07ef-4caa-b683-5847dbfbe5cc"
             } = server
    end

    test "a json doesn't contains server information \"data\" attribute" do
      json_body = %{
        "attributes" => %{
          "dbi_server_id" => "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
          "inserted_at" => "2025-03-22T20:07:30.766249Z",
          "name" => "Test",
          "updated_at" => "2025-05-04T18:48:44.213309Z",
          "url" => "http://localhost:4001"
        },
        "id" => "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
        "links" => %{},
        "meta" => %{},
        "relationships" => %{"dbi_server" => %{"links" => %{}, "meta" => %{}}},
        "type" => "dbi_server"
      }

      assert {:ok, server} = DBIServerTransformer.from_json(json_body)

      assert %{
               id: "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
               name: "Test",
               url: "http://localhost:4001",
               inserted_at: "2025-03-22T20:07:30.766249Z",
               updated_at: "2025-05-04T18:48:44.213309Z",
               dbi_server_id: "0c0647ec-07ef-4caa-b683-5847dbfbe5cc"
             } = server
    end

    test "a json has dbi_server_id as nil, then server's map has not :dbi_server_id key" do
      json_body = %{
        "attributes" => %{
          "inserted_at" => "2025-03-22T20:07:30.766249Z",
          "name" => "Test",
          "updated_at" => "2025-05-04T18:48:44.213309Z",
          "url" => "http://localhost:4001"
        },
        "id" => "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
        "links" => %{},
        "meta" => %{},
        "relationships" => %{},
        "type" => "dbi_server"
      }

      assert {:ok, server} = DBIServerTransformer.from_json(json_body)

      assert %{
               id: "0c0647ec-07ef-4caa-b683-5847dbfbe5cc",
               name: "Test",
               url: "http://localhost:4001",
               inserted_at: "2025-03-22T20:07:30.766249Z",
               updated_at: "2025-05-04T18:48:44.213309Z"
             } = server

      refute Map.has_key?(server, :dbi_server_id)
    end
  end
end
